Package: prevalence
Type: Package
Title: Tools for Prevalence Assessment Studies
Version: 0.4.1
Date: 2022-06-03
Authors@R: c(person("Brecht", "Devleesschauwer",
             role = c("aut", "cre"), email = "brechtdv@gmail.com"),
             person("Paul", "Torgerson", role = "aut"),
             person("Johannes", "Charlier", role = "aut"),
             person("Bruno", "Levecke", role = "aut"),
             person("Nicolas", "Praet", role = "aut"),
             person("Sophie", "Roelandt", role = "aut"),
             person("Suzanne", "Smit", role = "aut"),
             person("Pierre", "Dorny", role = "aut"),
             person("Dirk", "Berkvens", role = "aut"),
             person("Niko", "Speybroeck", role = "aut"))
Author: Brecht Devleesschauwer [aut, cre],
  Paul Torgerson [aut],
  Johannes Charlier [aut],
  Bruno Levecke [aut],
  Nicolas Praet [aut],
  Sophie Roelandt [aut],
  Suzanne Smit [aut],
  Pierre Dorny [aut],
  Dirk Berkvens [aut],
  Niko Speybroeck [aut]
Maintainer: Brecht Devleesschauwer <brechtdv@gmail.com>
BugReports: https://github.com/brechtdv/prevalence/issues
Description: The prevalence package provides Frequentist and Bayesian methods for prevalence assessment studies. IMPORTANT: the truePrev functions in the prevalence package call on JAGS (Just Another Gibbs Sampler), which therefore has to be available on the user's system. JAGS can be downloaded from <https://mcmc-jags.sourceforge.io/>.
Depends: R (>= 4.0.0)
Imports: methods, utils, stats, graphics, grDevices, coda, rjags
SystemRequirements: JAGS (>= 4.0.0) (see
        https://mcmc-jags.sourceforge.io/)
License: GPL (>= 2)
URL: http://prevalence.cbra.be/
LazyLoad: yes
NeedsCompilation: no
Packaged: 2022-06-03 21:00:31 UTC; BrDe394
Repository: CRAN
Date/Publication: 2022-06-03 21:20:02 UTC
Built: R 4.6.0; ; 2026-04-27 11:42:10 UTC; unix
