importFrom(methods, show)
importFrom(methods, new)
importFrom(utils, combn)
importFrom(utils, head)
importFrom(stats, density)
importFrom(stats, median)
importFrom(stats, optimize)
importFrom(stats, qbeta)
importFrom(stats, qnorm)
importFrom(stats, quantile)
importFrom(stats, sd)
importFrom(stats, var)
importFrom(graphics, plot)
importFrom(graphics, par)
importFrom(graphics, title)
importFrom(grDevices, devAskNewPage)
importFrom(rjags, jags.model)
importFrom(rjags, coda.samples)
importFrom(rjags, dic.samples)
importFrom(coda, gelman.diag)
importFrom(coda, gelman.plot)
importFrom(coda, densplot)
importFrom(coda, traceplot)
importFrom(coda, autocorr.plot)
importFrom(coda, HPDinterval)

export(truePrev)
export(truePrevPools)
export(truePrevMulti)
export(truePrevMulti2)
export(define_x)
export(define_prior)
export(define_prior2)
export(betaPERT)
export(betaExpert)
export(propCI)

S3method(print, betaPERT)
S3method(plot, betaPERT)
S3method(print, betaExpert)
S3method(plot, betaExpert)
S3method(print, prevModel)

exportClasses(prev)
exportMethods(show)
exportMethods(print)
exportMethods(summary)
exportMethods(as.matrix)
exportMethods(plot)
exportMethods(densplot)
exportMethods(traceplot)
exportMethods(autocorr.plot)
exportMethods(gelman.plot)
